View source: R/adaboost_probabilities.R
| adaboost_probabilities | R Documentation |
Class probabilities from model.
adaboost_probabilities(
input_model,
test,
verbose = getOption("mlpack.verbose", FALSE)
)
input_model |
Input AdaBoost model (AdaBoostModel). |
test |
Test dataset (numeric matrix). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
probabilities |
Predicted class probabilities for each point in the test set (numeric matrix). |
mlpack developers
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.