View source: R/decision_tree_probabilities.R
| decision_tree_probabilities | R Documentation |
Class predictions from train decision tree model.
decision_tree_probabilities(
input_model,
test,
test_labels = NA,
verbose = getOption("mlpack.verbose", FALSE)
)
input_model |
Pre-trained decision tree, to be used with test points (DecisionTreeModel). |
test |
Testing dataset (may contain categorical variables) (numeric matrix/data.frame with info). |
test_labels |
Test point labels, if accuracy calculation is desired (integer row). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
probabilities |
Class probabilities for each test point if probabilities has been selected (numeric matrix). |
mlpack developers
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.