View source: R/logistic_regression_classify.R
| predict.mlpack_logistic_regression | R Documentation |
An implementation of L2-regularized logistic regression for two-class classification. Uses a trained model to classify new points.
## S3 method for class 'mlpack_logistic_regression'
predict(object, newdata, type = c("predictions", "probabilities"), ...)
logistic_regression_classify(
input_model,
test,
decision_boundary = 0.5,
verbose = getOption("mlpack.verbose", FALSE)
)
object |
An instantiated model object for which prediction is desired |
newdata |
A test data set |
type |
A character value selection predictions or probabilities |
... |
Additional optional arguments affecting the prediction |
input_model |
Existing model (parameters) (LogisticRegression). |
test |
Matrix containing test dataset (numeric matrix). |
decision_boundary |
Decision boundary for prediction; if the logistic function for a point is less than the boundary, the class is taken to be 0; otherwise, the class is 1. Default value "0.5" (numeric). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
predictions |
If test data is specified, this matrix is where the predictions for the test set will be saved (integer row). |
mlpack developers
# \dontrun{ pred <- predict(model, newdata=X_test) }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.