logistic_regression_probabilities: L2-regularized Logistic Regression Probabilities

View source: R/logistic_regression_probabilities.R

logistic_regression_probabilitiesR Documentation

L2-regularized Logistic Regression Probabilities

Description

An implementation of L2-regularized logistic regression for two-class classification. Uses a trained model to classify new points and provide classification probabilities.

Usage

logistic_regression_probabilities(
  input_model,
  test,
  decision_boundary = 0.5,
  verbose = getOption("mlpack.verbose", FALSE)
)

Arguments

input_model

Existing model (parameters) (LogisticRegression).

test

Matrix containing test dataset (numeric matrix).

decision_boundary

Decision boundary for prediction; if the logistic function for a point is less than the boundary, the class is taken to be 0; otherwise, the class is 1. Default value "0.5" (numeric).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

Value

A list with several components defining the class attributes:

probabilities

Predicted class probabilities for each point in the test set (numeric matrix).

Author(s)

mlpack developers

Examples

# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }

mlpack documentation built on July 23, 2026, 1:08 a.m.