Learn R Programming

mlpack (version 4.8.0)

predict.mlpack_logistic_regression: L2-regularized Logistic Regression Classification

Description

An implementation of L2-regularized logistic regression for two-class classification. Uses a trained model to classify new points.

Usage

# S3 method for mlpack_logistic_regression
predict(object, newdata, type = c("predictions", "probabilities"), ...)

logistic_regression_classify( input_model, test, decision_boundary = 0.5, verbose = getOption("mlpack.verbose", FALSE) )

Value

A list with several components defining the class attributes:

predictions

If test data is specified, this matrix is where the predictions for the test set will be saved (integer row).

Arguments

object

An instantiated model object for which prediction is desired

newdata

A test data set

type

A character value selection predictions or probabilities

...

Additional optional arguments affecting the prediction

input_model

Existing model (parameters) (LogisticRegression).

test

Matrix containing test dataset (numeric matrix).

decision_boundary

Decision boundary for prediction; if the logistic function for a point is less than the boundary, the class is taken to be 0; otherwise, the class is 1. Default value "0.5" (numeric).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

Author

mlpack developers

Examples

Run this code
# \dontrun{ pred <- predict(model, newdata=X_test) }

Run the code above in your browser using DataLab