# For example, if we want to set all variables greater than 5 in the dataset
# "X" to 1 and variables less than or equal to 5.0 to 0, and save the result
# to "Y", we could run
#
# \dontrun{
# Y <- preprocess_binarize(input=X, threshold=5)
# }
#
# But if we want to apply this to only the first (0th) dimension of "X", we
# could instead run
#
# \dontrun{
# Y <- preprocess_binarize(input=X, threshold=5, dimension=0)
# }
Run the code above in your browser using DataLab