# So, a simple example where we want to print out statistical facts about the
# dataset "X" using the default settings, we could run
#
# \dontrun{
# preprocess_describe(input=X, verbose=TRUE)
# }
#
# If we want to customize the width to 10 and precision to 5 and consider the
# dataset as a population, we could run
#
# \dontrun{
# preprocess_describe(input=X, width=10, precision=5, verbose=TRUE)
# }
Run the code above in your browser using DataLab