View source: R/random_forest_probabilities.R
| random_forest_probabilities | R Documentation |
Class probabilities from random forest model.
random_forest_probabilities(
input_model,
test,
test_labels = NA,
verbose = getOption("mlpack.verbose", FALSE)
)
input_model |
Pre-trained random forest to use for classification (RandomForestModel). |
test |
Test dataset to produce predictions for (numeric matrix). |
test_labels |
Test dataset labels, if accuracy calculation is desired (integer row). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
probabilities |
Predicted class probabilities for each point in the test set (numeric matrix). |
mlpack developers
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.