View source: R/adaboost_classify.R
| adaboost_classify | R Documentation |
Class predictions from model.
adaboost_classify(
input_model,
test,
verbose = getOption("mlpack.verbose", FALSE)
)
## S3 method for class 'mlpack_adaboost'
predict(object, newdata, type = c("predictions", "probabilities"), ...)
input_model |
Input AdaBoost model (AdaBoostModel). |
test |
Test dataset (numeric matrix). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
object |
An instantiated model object for which prediction is desired |
newdata |
A test data set |
type |
A character value selection predictions or probabilities |
... |
Additional optional arguments affecting the prediction |
A list with several components defining the class attributes:
predictions |
Predicted labels for the test set (integer row). |
mlpack developers
# \dontrun{ pred <- predict(model, newdata=X_test) }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.