Learn R Programming

mlpack (version 4.8.0)

adaboost_classify: AdaBoost Prediction

Description

Class predictions from model.

Usage

adaboost_classify(
  input_model,
  test,
  verbose = getOption("mlpack.verbose", FALSE)
)

# S3 method for mlpack_adaboost predict(object, newdata, type = c("predictions", "probabilities"), ...)

Value

A list with several components defining the class attributes:

predictions

Predicted labels for the test set (integer row).

Arguments

input_model

Input AdaBoost model (AdaBoostModel).

test

Test dataset (numeric matrix).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

object

An instantiated model object for which prediction is desired

newdata

A test data set

type

A character value selection predictions or probabilities

...

Additional optional arguments affecting the prediction

Author

mlpack developers

Examples

Run this code
# \dontrun{ pred <- predict(model, newdata=X_test) }

Run the code above in your browser using DataLab