Learn R Programming

mlpack (version 4.8.0)

adaboost_probabilities: AdaBoost Probability Prediction

Description

Class probabilities from model.

Usage

adaboost_probabilities(
  input_model,
  test,
  verbose = getOption("mlpack.verbose", FALSE)
)

Value

A list with several components defining the class attributes:

probabilities

Predicted class probabilities for each point in the test set (numeric matrix).

Arguments

input_model

Input AdaBoost model (AdaBoostModel).

test

Test dataset (numeric matrix).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

Author

mlpack developers

Examples

Run this code
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }

Run the code above in your browser using DataLab