View source: R/bayesian_linear_regression_predict.R
| bayesian_linear_regression_predict | R Documentation |
An implementation of the Bayesian linear regression prediction: Given a pre-trained model and a test data set, it provides model predictions.
bayesian_linear_regression_predict(
input_model,
test,
stddevs = FALSE,
verbose = getOption("mlpack.verbose", FALSE)
)
input_model |
Trained BayesianLinearRegression model to use (BayesianLinearRegression). |
test |
Matrix containing points to regress on (test points) (numeric matrix). |
stddevs |
Return standard deviations along with predictions. Default value "FALSE" (logical). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
predictions |
Matrix of predicted responses, with associated standard deviations if option selected (numeric matrix). |
mlpack developers
# \dontrun{ pred <- predict(model, newdata=X_test) }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.