Learn R Programming

mlpack (version 4.8.0)

bayesian_linear_regression_predict: BayesianLinearRegression Prediction

Description

An implementation of the Bayesian linear regression prediction: Given a pre-trained model and a test data set, it provides model predictions.

Usage

bayesian_linear_regression_predict(
  input_model,
  test,
  stddevs = FALSE,
  verbose = getOption("mlpack.verbose", FALSE)
)

Value

A list with several components defining the class attributes:

predictions

Matrix of predicted responses, with associated standard deviations if option selected (numeric matrix).

Arguments

input_model

Trained BayesianLinearRegression model to use (BayesianLinearRegression).

test

Matrix containing points to regress on (test points) (numeric matrix).

stddevs

Return standard deviations along with predictions. Default value "FALSE" (logical).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

Author

mlpack developers

Examples

Run this code
# \dontrun{ pred <- predict(model, newdata=X_test) }

Run the code above in your browser using DataLab