| predict.mlpack_lars | R Documentation |
An implementation of Least Angle Regression (stagewise/lasso), also known as LARS. This program can use a pre-trained LARS/LASSO/Elastic Net model to output regression predictions from a test set.
## S3 method for class 'mlpack_lars'
predict(object, newdata, ...)
lars_predict(input_model, test, verbose = getOption("mlpack.verbose", FALSE))
object |
An instantiated model object for which prediction is desired |
newdata |
A test data set |
... |
Additional optional arguments affecting the prediction |
input_model |
Trained LARS model to use (LARS). |
test |
Matrix containing points to regress on (test points) (numeric matrix). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
predictions |
Matrix containing predicted responses (numeric matrix). |
mlpack developers
# \dontrun{ pred <- predict(model, newdata=X_test) }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.