View source: R/linear_regression_predict.R
| predict.mlpack_linear_regression | R Documentation |
Predictions from model.
## S3 method for class 'mlpack_linear_regression'
predict(object, newdata, ...)
linear_regression_predict(
input_model,
test,
verbose = getOption("mlpack.verbose", FALSE)
)
object |
An instantiated model object for which prediction is desired |
newdata |
A test data set |
... |
Additional optional arguments affecting the prediction |
input_model |
Existing LinearRegression model to use (LinearRegression). |
test |
Matrix containing X' (test regressors) (numeric matrix). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
output_predictions |
Matrix containing predicted responses (numeric row). |
mlpack developers
# \dontrun{ pred <- predict(model, newdata=X_test) }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.