View source: R/logistic_regression_probabilities.R
| logistic_regression_probabilities | R Documentation |
An implementation of L2-regularized logistic regression for two-class classification. Uses a trained model to classify new points and provide classification probabilities.
logistic_regression_probabilities(
input_model,
test,
decision_boundary = 0.5,
verbose = getOption("mlpack.verbose", FALSE)
)
input_model |
Existing model (parameters) (LogisticRegression). |
test |
Matrix containing test dataset (numeric matrix). |
decision_boundary |
Decision boundary for prediction; if the logistic function for a point is less than the boundary, the class is taken to be 0; otherwise, the class is 1. Default value "0.5" (numeric). |
verbose |
Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical). |
A list with several components defining the class attributes:
probabilities |
Predicted class probabilities for each point in the test set (numeric matrix). |
mlpack developers
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.