Learn R Programming

mlpack (version 4.8.0)

logistic_regression_probabilities: L2-regularized Logistic Regression Probabilities

Description

An implementation of L2-regularized logistic regression for two-class classification. Uses a trained model to classify new points and provide classification probabilities.

Usage

logistic_regression_probabilities(
  input_model,
  test,
  decision_boundary = 0.5,
  verbose = getOption("mlpack.verbose", FALSE)
)

Value

A list with several components defining the class attributes:

probabilities

Predicted class probabilities for each point in the test set (numeric matrix).

Arguments

input_model

Existing model (parameters) (LogisticRegression).

test

Matrix containing test dataset (numeric matrix).

decision_boundary

Decision boundary for prediction; if the logistic function for a point is less than the boundary, the class is taken to be 0; otherwise, the class is 1. Default value "0.5" (numeric).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

Author

mlpack developers

Examples

Run this code
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }

Run the code above in your browser using DataLab