A list with several components defining the class attributes:
predictions
Predicted classes for each point in the test set
(integer row).
Arguments
input_model
Pre-trained random forest to use for classification
(RandomForestModel).
test
Test dataset to produce predictions for (numeric matrix).
test_labels
Test dataset labels, if accuracy calculation is
desired (integer row).
verbose
Display informational messages and the full list of
parameters and timers at the end of execution. Default value
"getOption("mlpack.verbose", FALSE)" (logical).