Learn R Programming

mlpack (version 4.8.0)

random_forest_probabilities: Random Forests Probabilities

Description

Class probabilities from random forest model.

Usage

random_forest_probabilities(
  input_model,
  test,
  test_labels = NA,
  verbose = getOption("mlpack.verbose", FALSE)
)

Value

A list with several components defining the class attributes:

probabilities

Predicted class probabilities for each point in the test set (numeric matrix).

Arguments

input_model

Pre-trained random forest to use for classification (RandomForestModel).

test

Test dataset to produce predictions for (numeric matrix).

test_labels

Test dataset labels, if accuracy calculation is desired (integer row).

verbose

Display informational messages and the full list of parameters and timers at the end of execution. Default value "getOption("mlpack.verbose", FALSE)" (logical).

Author

mlpack developers

Examples

Run this code
# \dontrun{ prob <- predict(model, newdata=X_test, type="probabilities") }

Run the code above in your browser using DataLab